@@ -6,10 +6,13 @@ import (
 	"os"
 
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/common"
-	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/controller/dashboard"
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/controller/knativeserving/consoleclidownload"
 	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/controller/knativeserving/quickstart"
+	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/monitoring"
+	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/monitoring/dashboards"
+	socommon "github.com/openshift-knative/serverless-operator/pkg/common"
 	consolev1 "github.com/openshift/api/console/v1"
+	routev1 "github.com/openshift/api/route/v1"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
@@ -19,7 +22,7 @@ import (
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/sets"
-	servingv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
+	operatorv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/controller"
 	"sigs.k8s.io/controller-runtime/pkg/controller/controllerutil"
@@ -45,7 +48,7 @@ const (
 
 	// certVersionKey is an annotation key used by the Serverless operator to annotate the Knative Serving
 	// controller's PodTemplate to make it redeploy on certificate changes.
-	certVersionKey = "serving.knative.openshift.io/mounted-cert-version"
+	certVersionKey = socommon.ServingDownstreamDomain + "/mounted-cert-version"
 
 	requiredNsEnvName = "REQUIRED_SERVING_NAMESPACE"
 )
@@ -85,7 +88,7 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 
 	// Watch for changes to primary resource KnativeServing, only in the expected namespace.
 	requiredNs := os.Getenv(requiredNsEnvName)
-	err = c.Watch(&source.Kind{Type: &servingv1alpha1.KnativeServing{}}, &handler.EnqueueRequestForObject{}, predicate.NewPredicateFuncs(func(obj client.Object) bool {
+	err = c.Watch(&source.Kind{Type: &operatorv1alpha1.KnativeServing{}}, &handler.EnqueueRequestForObject{}, predicate.NewPredicateFuncs(func(obj client.Object) bool {
 		if requiredNs == "" {
 			return true
 		}
@@ -97,7 +100,7 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 
 	// Watch for changes to owned ConfigMaps
 	err = c.Watch(&source.Kind{Type: &corev1.ConfigMap{}}, &handler.EnqueueRequestForOwner{
-		OwnerType:    &servingv1alpha1.KnativeServing{},
+		OwnerType:    &operatorv1alpha1.KnativeServing{},
 		IsController: true,
 	})
 	if err != nil {
@@ -106,9 +109,10 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 
 	gvkToResource := map[schema.GroupVersionKind]client.Object{
 		consolev1.GroupVersion.WithKind("ConsoleCLIDownload"): &consolev1.ConsoleCLIDownload{},
+		routev1.GroupVersion.WithKind("Route"):                &routev1.Route{},
 	}
 	for _, t := range gvkToResource {
-		err = c.Watch(&source.Kind{Type: t}, common.EnqueueRequestByOwnerAnnotations(common.ServingOwnerName, common.ServingOwnerNamespace))
+		err = c.Watch(&source.Kind{Type: t}, common.EnqueueRequestByOwnerAnnotations(socommon.ServingOwnerName, socommon.ServingOwnerNamespace))
 		if err != nil {
 			return err
 		}
@@ -134,7 +138,7 @@ func (r *ReconcileKnativeServing) Reconcile(ctx context.Context, request reconci
 	reqLogger.Info("Reconciling KnativeServing")
 
 	// Fetch the KnativeServing instance
-	original := &servingv1alpha1.KnativeServing{}
+	original := &operatorv1alpha1.KnativeServing{}
 	err := r.client.Get(context.TODO(), request.NamespacedName, original)
 	if err != nil {
 		if errors.IsNotFound(err) {
@@ -156,17 +160,17 @@ func (r *ReconcileKnativeServing) Reconcile(ctx context.Context, request reconci
 		}
 	}
 
-	common.KnativeServingUpG = common.KnativeUp.WithLabelValues("serving_status")
+	monitoring.KnativeServingUpG = monitoring.KnativeUp.WithLabelValues("serving_status")
 	if instance.Status.IsReady() {
-		common.KnativeServingUpG.Set(1)
+		monitoring.KnativeServingUpG.Set(1)
 	} else {
-		common.KnativeServingUpG.Set(0)
+		monitoring.KnativeServingUpG.Set(0)
 	}
 	return reconcile.Result{}, reconcileErr
 }
 
-func (r *ReconcileKnativeServing) reconcileKnativeServing(instance *servingv1alpha1.KnativeServing) error {
-	stages := []func(*servingv1alpha1.KnativeServing) error{
+func (r *ReconcileKnativeServing) reconcileKnativeServing(instance *operatorv1alpha1.KnativeServing) error {
+	stages := []func(*operatorv1alpha1.KnativeServing) error{
 		r.configure,
 		r.ensureFinalizers,
 		r.ensureCustomCertsConfigMap,
@@ -183,7 +187,7 @@ func (r *ReconcileKnativeServing) reconcileKnativeServing(instance *servingv1alp
 }
 
 // configure default settings for OpenShift
-func (r *ReconcileKnativeServing) configure(instance *servingv1alpha1.KnativeServing) error {
+func (r *ReconcileKnativeServing) configure(instance *operatorv1alpha1.KnativeServing) error {
 	before := instance.DeepCopy()
 	if err := common.Mutate(instance, r.client); err != nil {
 		return err
@@ -201,7 +205,7 @@ func (r *ReconcileKnativeServing) configure(instance *servingv1alpha1.KnativeSer
 }
 
 // set a finalizer to clean up service mesh when instance is deleted
-func (r *ReconcileKnativeServing) ensureFinalizers(instance *servingv1alpha1.KnativeServing) error {
+func (r *ReconcileKnativeServing) ensureFinalizers(instance *operatorv1alpha1.KnativeServing) error {
 	for _, finalizer := range instance.GetFinalizers() {
 		if finalizer == finalizerName {
 			return nil
@@ -213,7 +217,7 @@ func (r *ReconcileKnativeServing) ensureFinalizers(instance *servingv1alpha1.Kna
 }
 
 // create the configmap to be injected with custom certs
-func (r *ReconcileKnativeServing) ensureCustomCertsConfigMap(instance *servingv1alpha1.KnativeServing) error {
+func (r *ReconcileKnativeServing) ensureCustomCertsConfigMap(instance *operatorv1alpha1.KnativeServing) error {
 	certs := instance.Spec.ControllerCustomCerts
 
 	// If the user doesn't specify anything else, this is set by the webhook/controller defaulter to
@@ -274,7 +278,7 @@ func (r *ReconcileKnativeServing) ensureCustomCertsConfigMap(instance *servingv1
 	return nil
 }
 
-func (r *ReconcileKnativeServing) reconcileConfigMap(instance *servingv1alpha1.KnativeServing, name string,
+func (r *ReconcileKnativeServing) reconcileConfigMap(instance *operatorv1alpha1.KnativeServing, name string,
 	annotations, labels map[string]string, data map[string]string) (*corev1.ConfigMap, error) {
 	ctx := context.TODO()
 	cm := &corev1.ConfigMap{}
@@ -326,23 +330,24 @@ func (r *ReconcileKnativeServing) reconcileConfigMap(instance *servingv1alpha1.K
 	return cm, nil
 }
 
-func (r *ReconcileKnativeServing) installQuickstarts(instance *servingv1alpha1.KnativeServing) error {
+func (r *ReconcileKnativeServing) installQuickstarts(instance *operatorv1alpha1.KnativeServing) error {
 	return quickstart.Apply(instance, r.client)
 }
 
 // installKnConsoleCLIDownload creates CR for kn CLI download link
-func (r *ReconcileKnativeServing) installKnConsoleCLIDownload(instance *servingv1alpha1.KnativeServing) error {
+func (r *ReconcileKnativeServing) installKnConsoleCLIDownload(instance *operatorv1alpha1.KnativeServing) error {
 	return consoleclidownload.Apply(instance, r.client, r.scheme)
 }
 
 // installDashboard installs dashboard for OpenShift webconsole
-func (r *ReconcileKnativeServing) installDashboard(instance *servingv1alpha1.KnativeServing) error {
-	return dashboard.Apply(os.Getenv(dashboard.ServingResourceDashboardPathEnvVar), instance, r.client)
+func (r *ReconcileKnativeServing) installDashboard(instance *operatorv1alpha1.KnativeServing) error {
+	log.Info("Installing Serving Dashboards")
+	return dashboards.Apply("serving", instance, r.client)
 }
 
 // general clean-up, mostly resources in different namespaces from servingv1alpha1.KnativeServing.
-func (r *ReconcileKnativeServing) delete(instance *servingv1alpha1.KnativeServing) error {
-	defer common.KnativeUp.DeleteLabelValues("serving_status")
+func (r *ReconcileKnativeServing) delete(instance *operatorv1alpha1.KnativeServing) error {
+	defer monitoring.KnativeUp.DeleteLabelValues("serving_status")
 	finalizers := sets.NewString(instance.GetFinalizers()...)
 
 	if !finalizers.Has(finalizerName) {
@@ -356,8 +361,8 @@ func (r *ReconcileKnativeServing) delete(instance *servingv1alpha1.KnativeServin
 		return fmt.Errorf("failed to delete kn ConsoleCLIDownload: %w", err)
 	}
 
-	log.Info("Deleting dashboard")
-	if err := dashboard.Delete(os.Getenv(dashboard.ServingResourceDashboardPathEnvVar), instance, r.client); err != nil {
+	log.Info("Deleting Serving dashboards")
+	if err := dashboards.Delete("serving", instance, r.client); err != nil {
 		return fmt.Errorf("failed to delete dashboard configmap: %w", err)
 	}
 
@@ -367,7 +372,7 @@ func (r *ReconcileKnativeServing) delete(instance *servingv1alpha1.KnativeServin
 	}
 
 	// The above might take a while, so we refetch the resource again in case it has changed.
-	refetched := &servingv1alpha1.KnativeServing{}
+	refetched := &operatorv1alpha1.KnativeServing{}
 	if err := r.client.Get(context.TODO(), types.NamespacedName{Namespace: instance.Namespace, Name: instance.Name}, refetched); err != nil {
 		return fmt.Errorf("failed to refetch KnativeServing: %w", err)
 	}
