@@ -10,9 +10,9 @@ import (
 	"time"
 
 	"github.com/openshift-knative/serverless-operator/test"
-	v1 "github.com/openshift/api/route/v1"
+	routev1 "github.com/openshift/api/route/v1"
 	corev1 "k8s.io/api/core/v1"
-	meta "k8s.io/apimachinery/pkg/apis/meta/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/wait"
 
 	prom "github.com/prometheus/client_golang/api"
@@ -41,6 +41,22 @@ var (
 		"mt_broker_ingress_go_mallocs",
 		"sugar_controller_go_mallocs",
 	}
+
+	KafkaQueries = []string{
+		"kafkachannel_controller_go_mallocs",
+		"kafka_controller_go_mallocs",
+		"kafkachannel_webhook_go_mallocs",
+		"kafkachannel_dispatcher_go_mallocs",
+	}
+
+	serverlessComponentQueries = []string{
+		// Checks if openshift-knative-operator metrics are served
+		"knative_operator_go_mallocs",
+		// Checks if knative-openshift metrics are served
+		"controller_runtime_active_workers{controller=\"knativeserving-controller\"}",
+		// Checks if knative-openshift-ingress metrics are served
+		"openshift_ingress_controller_go_mallocs",
+	}
 )
 
 type authRoundtripper struct {
@@ -79,8 +95,8 @@ func newPrometheusClient(caCtx *test.Context) (promv1.API, error) {
 	return promv1.NewAPI(client), nil
 }
 
-func getPrometheusRoute(caCtx *test.Context) (*v1.Route, error) {
-	r, err := caCtx.Clients.Route.Routes("openshift-monitoring").Get(context.Background(), "prometheus-k8s", meta.GetOptions{})
+func getPrometheusRoute(caCtx *test.Context) (*routev1.Route, error) {
+	r, err := caCtx.Clients.Route.Routes("openshift-monitoring").Get(context.Background(), "prometheus-k8s", metav1.GetOptions{})
 	if err != nil {
 		return nil, fmt.Errorf("error getting Prometheus route: %w", err)
 	}
@@ -96,7 +112,8 @@ func VerifyHealthStatusMetric(caCtx *test.Context, label string, expectedValue s
 	if err := wait.PollImmediate(test.Interval, prometheusTargetTimeout, func() (bool, error) {
 		value, _, err := pc.Query(context.Background(), fmt.Sprintf(`knative_up{type="%s"}`, label), time.Time{})
 		if err != nil {
-			return false, err
+			caCtx.T.Log("Error querying prometheus metrics:", err)
+			return false, nil
 		}
 
 		vec, ok := value.(prommodel.Vector)
@@ -116,7 +133,7 @@ func VerifyHealthStatusMetric(caCtx *test.Context, label string, expectedValue s
 	return nil
 }
 
-func VerifyControlPlaneMetrics(caCtx *test.Context, metricQueries []string) error {
+func VerifyMetrics(caCtx *test.Context, metricQueries []string) error {
 	pc, err := newPrometheusClient(caCtx)
 	if err != nil {
 		return err
@@ -126,7 +143,8 @@ func VerifyControlPlaneMetrics(caCtx *test.Context, metricQueries []string) erro
 		if err := wait.PollImmediate(test.Interval, prometheusTargetTimeout, func() (bool, error) {
 			value, _, err := pc.Query(context.Background(), metric, time.Time{})
 			if err != nil {
-				return false, err
+				caCtx.T.Log("Error querying prometheus metrics:", err)
+				return false, nil
 			}
 			return value.Type() == prommodel.ValVector, nil
 		}); err != nil {
@@ -137,17 +155,17 @@ func VerifyControlPlaneMetrics(caCtx *test.Context, metricQueries []string) erro
 }
 
 func getBearerTokenForPrometheusAccount(caCtx *test.Context) (string, error) {
-	sa, err := caCtx.Clients.Kube.CoreV1().ServiceAccounts("openshift-monitoring").Get(context.Background(), "prometheus-k8s", meta.GetOptions{})
+	sa, err := caCtx.Clients.Kube.CoreV1().ServiceAccounts("openshift-monitoring").Get(context.Background(), "prometheus-k8s", metav1.GetOptions{})
 	if err != nil {
-		return "", fmt.Errorf("error getting service account prometheus-k8s %v", err)
+		return "", fmt.Errorf("error getting service account prometheus-k8s: %w", err)
 	}
 	tokenSecret := getSecretNameForToken(sa.Secrets)
 	if tokenSecret == "" {
 		return "", errors.New("token name for prometheus-k8s service account not found")
 	}
-	sec, err := caCtx.Clients.Kube.CoreV1().Secrets("openshift-monitoring").Get(context.Background(), tokenSecret, meta.GetOptions{})
+	sec, err := caCtx.Clients.Kube.CoreV1().Secrets("openshift-monitoring").Get(context.Background(), tokenSecret, metav1.GetOptions{})
 	if err != nil {
-		return "", fmt.Errorf("error getting secret %s %v", tokenSecret, err)
+		return "", fmt.Errorf("error getting secret %s: %w", tokenSecret, err)
 	}
 	tokenContents := sec.Data["token"]
 	if len(tokenContents) == 0 {
